@@ -1,7 +1,10 @@
-__version__ = '1.0.1'
+__version__ = '1.0.4'
+
 from jsw_nx.base.set import set
 from jsw_nx.base.forin import forin
 from jsw_nx.base.get import get
 from jsw_nx.base.indexof import indexof
 from jsw_nx.base.includes import includes
+from jsw_nx.base.find import find
+from jsw_nx.base.find_index import find_index
 from jsw_nx.packages.days import days
